# ListSecurityGroupsResponse

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**page_number** | **int** |  | 
**page_size** | **int** |  | 
**security_groups** | [**list[SecurityGroup]**](SecurityGroup.md) |  | 
**total_count** | **int** |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


